# KubeResearch

[![PyPI](https://img.shields.io/pypi/v/kubr?style=flat-square)](https://pypi.python.org/pypi/kubr/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/kubr?style=flat-square)](https://pypi.python.org/pypi/kubr/)
[![PyPI - License](https://img.shields.io/pypi/l/kubr?style=flat-square)](https://pypi.python.org/pypi/kubr/)


---

**Documentation**: [https://kuberesearch.readthedocs.io/](https://kuberesearch.readthedocs.io/)

**PyPI**: [https://pypi.org/project/kubr/](https://pypi.org/project/kubr/)

---

KubeResearch is a project for running research experiments on Kubernetes.

## Installation

```sh
pip install kubr
```